@@ -1,10 +1,7 @@
 """
 Populates a ConfigurationModel by deserializing JSON data contained in a file.
 """
-
-
 import os
-import io
 
 from django.core.management.base import BaseCommand, CommandError
 from django.utils.translation import ugettext_lazy as _
@@ -75,6 +72,6 @@ class Command(BaseCommand):
             raise CommandError(_("File {0} does not exist").format(json_file))
 
         self.stdout.write(_("Importing JSON data from file {0}").format(json_file))
-        with io.open(json_file, "rb") as data:
+        with open(json_file, "rb") as data:
             created_entries = deserialize_json(data, options['username'])
             self.stdout.write(_("Import complete, {0} new entries created").format(created_entries))
